@@ -9,8 +9,8 @@ template classes test
 class 
 BTreeWindow: public VDKForm
 {
-  VDKText *text; 
-  VDKLabelButton *start,*quit,*showsource;
+  VDKTextView *text; 
+  VDKCustomButton *start,*quit,*showsource;
  public:
   BTreeWindow(VDKApplication* owner):
     VDKForm(owner,"Sorted lists,Btrees and Heaps example")  {}
