@@ -1,6 +1,28 @@
 /*
-file:dnd.cc
-*/
+ * ===========================
+ * VDK Visual Develeopment Kit
+ * Version 2.0.0
+ * november 2000
+ * ===========================
+ *
+ * Copyright (C) 1998, Mario Motta
+ * Developed by Mario Motta <mmotta@guest.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
 #include "dnd.h"
 
 enum {
@@ -17,7 +39,7 @@ static GtkTargetEntry target_table[] = {
 };
 
 static guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
-static char *drag_icon_xpm[];
+extern char *drag_icon_xpm[];
 /*
 main form constructor
 */
@@ -60,15 +82,15 @@ DndForm::GUISetup(void)
   button_area->SetSize(86,131);
   hbox4->Add(button_area,0,1,1,0);
   button_area->BorderWidth(0);
-  button1 = new VDKLabelButton(this,"button1");
+  button1 = new VDKCustomButton(this,"button1");
   button_area->Add(button1,0,1,1,0);
-  button2 = new VDKLabelButton(this,"button2");
+  button2 = new VDKCustomButton(this,"button2");
   button_area->Add(button2,0,1,1,0);
-  button3 = new VDKLabelButton(this,"button3");
+  button3 = new VDKCustomButton(this,"button3");
   button_area->Add(button3,0,1,1,0);
-  button4 = new VDKLabelButton(this,"button4");
+  button4 = new VDKCustomButton(this,"button4");
   button_area->Add(button4,0,1,1,0);
-  button6 = new VDKLabelButton(this,"button6");
+  button6 = new VDKCustomButton(this,"button6");
   button_area->Add(button6,0,1,1,0);
   widget_area = new VDKBox(this,v_box);
   widget_area->SetSize(73,134);
@@ -229,7 +251,7 @@ TrashcanForm::GUISetup(void)
   VBox13 = new VDKBox(this,v_box);
   frame1->Add(VBox13,l_justify,1,1,0);
   VBox13->BorderWidth(0);
-  vbox1 = new VDKBox(this,v_box);
+  VDKEventBox* vbox1 = new VDKEventBox(this,v_box);
   VBox13->Add(vbox1,0,1,1,0);
   vbox1->BorderWidth(0);
   trashcan = new VDKPixmap(this,trashcan_closed_xpm);
@@ -521,7 +543,7 @@ char * trashcan_open_xpm[] = {
 "                                                                ",
 "                                                                "};
 /* XPM */
-static char *drag_icon_xpm[]={
+char* drag_icon_xpm[]={
 "16 14 5 1",
 "a c #d9d9d9",
 "c c #7f7f7f",
