@@ -27,6 +27,7 @@
 #include <cstring>
 #include "testvdk.h"
 #include <vdk/vdk.h>
+#include <vdk/vdkfilechooser.h>
 #include "vdk/FileDialog.h"
 #include "chartcompo.h"
 #include "ctreecompo.h"
@@ -70,8 +71,15 @@ defining signal static table
 DEFINE_SIGNAL_MAP(TestvdkForm,VDKForm)
   ON_SIGNAL(quitMenu,activate_signal,OnquitMenuActivate),
   ON_SIGNAL(openMenu,activate_signal,OnopenMenuActivate),
+  ON_SIGNAL(filechooser,activate_signal,OnfilechooserActivate),
   ON_SIGNAL(testlist,row_activated_signal,OnTestIt),
-  ON_SIGNAL(testlist,click_column_signal,OnTestIt)
+  ON_SIGNAL(testlist,click_column_signal,OnTestIt),
+  //
+  ON_SIGNAL(cbentry,activate_signal,OnComboEntryActivated),
+  ON_SIGNAL(cbentry,changed_signal,OnComboEntryChanged),
+  ON_SIGNAL(cbentry,focus_in_signal,OnComboEntryFocusIn),
+  ON_SIGNAL(cbentry,focus_out_signal,OnComboEntryFocusOut),
+  ON_SIGNAL(chbox,toggled_signal,OnCheckBoxToggled)
 END_SIGNAL_MAP
 
 /*
@@ -102,7 +110,7 @@ struct
 /*
   test name            creator static function        source/member             widget  tested
 */
-  {"Buttons",          TestvdkForm::CreateButtons     ,NULL, "CreateButtons"    ,NULL,  false},
+  {"Buttons & C.",     TestvdkForm::CreateButtons     ,NULL, "CreateButtons"    ,NULL,  false},
   {"Canvas ",          TestvdkForm::CreateCanvas      ,"canvascompo", NULL      ,NULL,  false},
   {"Combo box ",       TestvdkForm::CreateCombo       ,"combocompo", NULL       ,NULL,  false},
   {"Chart",            TestvdkForm::CreateChart       ,"chartcompo", NULL       ,NULL,  false},
@@ -486,11 +494,17 @@ has flown more than 1500 hours on this airplane";
   CREATES BUTTONS TEST
   =========================
 */
+static char *completion_list[] =
+{
+  "vdk","vdkbuilder","vdk version 2.0.4","gtk+","gtk+ version 2.0.4",
+  "open source model is great","open the door","gnome","gnomify",NULL
+};
+
 VDKObject* 
 TestvdkForm::CreateButtons(VDKForm* owner)
 {
   int t = 0;
-  VDKTable* table = new VDKTable(owner,6,2,true);
+  VDKTable* table = new VDKTable(owner,7,2,true);
   // attaches 9 buttons
   VDKObject* buttons[] = { NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL };
   buttons[0] = new VDKCustomButton(owner,"A _labeled button");
@@ -532,6 +546,13 @@ TestvdkForm::CreateButtons(VDKForm* owner)
 
   for(t = 0; buttons[t];t++)
     table->AddToCell(buttons[t],t/2,t%2,!GTK_FILL | !GTK_EXPAND,5);
+  //
+  VDKEntry* entry = new VDKEntry(owner);
+  entry->NormalBackground = VDKRgb("lemon chiffon");
+  entry->SetCompletion(completion_list);
+  entry->AddCompletionItem("vdk porting to win is ready");
+  table->AddToCell(entry,4,1,!GTK_FILL | !GTK_EXPAND,5);
+  entry->SetTip("completion enabled, try: vdk,gtk or open");
 
   VDKRadioButtonGroup *rbg = new VDKRadioButtonGroup(owner);
   VDKRadioButton* rb = new VDKRadioButton(rbg,"A radio button");
@@ -547,8 +568,129 @@ TestvdkForm::CreateButtons(VDKForm* owner)
   rb = new VDKRadioButton(owner,"A stand-alone radio button");
   abox->Add(rb);
   table->AddToCell(abox,5,1,!GTK_FILL | !GTK_EXPAND,5);
+
+  abox = new VDKBox(owner);
+  VDKLabel* label = new VDKLabel(owner,"A VDKComboEntry widget");
+  abox->Add(label);
+  table->AddToCell(abox,6,0,!GTK_FILL | !GTK_EXPAND,5);
+
+  TestvdkForm* form = dynamic_cast<TestvdkForm*>(owner);
+  if(form)
+    {
+      form->chbox = new VDKCheckButton(owner,"Sorted");
+      abox->Add(form->chbox);
+      StringList list;
+      for(int t = 0; completion_list[t];t++)
+	list.add(completion_list[t]);
+      form->cbentry = new VDKComboEntry(form/*,completion_list*/);
+      //      form->cbentry->Font = new VDKFont(owner,"sans bold 10"); 
+      form->cbentry->Selections = &list;
+      // form->cbentry->Editable = false;
+      form->cbentry->Selected = 0;
+      form->cbentry->NormalBackground = VDKRgb("skyblue2");
+      form->cbentry->Foreground = VDKRgb("navy blue");
+      form->cbentry->SetTip("Hit \"Enter\" and text will added to\ndropdown list (if not already in)");
+      gtk_widget_set_name (form->cbentry->Widget(), "list-combo");      
+      table->AddToCell(form->cbentry,6,1,!GTK_FILL | !GTK_EXPAND,5);
+
+    }
   return table;
 }
+
+
+bool 
+TestvdkForm::OnCheckBoxToggled(VDKObject* sender)
+{
+  static StringList *unsorted = NULL;
+  //GtkListStore* store = cbentry->StoreModel;
+  // store unsorted dropdown list for later use
+  if(!unsorted)
+    unsorted = cbentry->Selections;
+  if(chbox->Checked)
+    {
+      // cbentry->SortingOrder = GTK_SORT_DESCENDING;
+      cbentry->Sorted = true;
+    }
+  else
+    /*
+      since once sorted cannot revert to previous state
+      we substitute store model with a new unsorted one
+     */
+    {
+      cbentry->Sorted = false;
+      GtkListStore* store = gtk_list_store_new (1, G_TYPE_STRING);
+      cbentry->StoreModel = store;
+      cbentry->Selections = unsorted;
+    }
+  cbentry->Selected = 0;
+  return true;
+} 
+
+bool
+TestvdkForm::OnComboEntryActivated(VDKObject* sender)
+{
+  GtkTreeIter iter;
+  gchar *item = NULL;  
+  bool add_flag = true;
+  char* text = (char*) cbentry->Text;
+  printf("\nVDKComboEntry activated - text:%s",text);
+  fflush(stdout);  
+  // gets underlying store list
+  GtkListStore* store = cbentry->StoreModel;
+  for(bool flag = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store),&iter);
+      flag; flag = gtk_tree_model_iter_next(GTK_TREE_MODEL(store),&iter))
+    {
+      gtk_tree_model_get (GTK_TREE_MODEL(store), &iter, 0, &item, -1);
+      if(!strcmp(item,text))
+	{
+	  add_flag = false;
+	  break;
+	}
+    }
+  // add entry text if not unique in dropdown list
+  if(add_flag)
+    {
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (store, &iter, 0, text, -1);
+      printf("\nVDKComboEntry added:%s to dropdown list",text);
+      fflush(stdout);
+    }
+  delete[] text;
+  return true;
+}
+
+bool
+TestvdkForm::OnComboEntryChanged(VDKObject* sender)
+{
+  VDKComboEntry* cbentry = dynamic_cast<VDKComboEntry*>(sender);
+  if(cbentry)
+    {
+      char* selected = (char*) cbentry->Text;
+      int index = cbentry->Selected;
+      printf("\nVDKComboEntry - index: %d - text:%s",index , selected);
+      fflush(stdout);
+      delete[] selected;
+    }
+  return true;
+}
+bool
+TestvdkForm::OnComboEntryFocusIn(VDKObject* sender)
+{
+  /*
+  printf("\nVDKComboEntry <%p> get focus !",sender);
+  fflush(stdout);
+  */
+  return true;
+}
+bool
+TestvdkForm::OnComboEntryFocusOut(VDKObject* sender)
+{
+  /*
+  printf("\nVDKComboEntry <%p> lost focus !",sender);
+  fflush(stdout);
+  */
+  return true;
+}
 ////////////////////////////////////////////////////////////////////
 
 /*
@@ -573,11 +715,11 @@ TestvdkForm::~TestvdkForm()
 */
 
 static char* introduction =
-"<span foreground=\"sienna\" font_desc=\"times bold 16\">"
-"\t\tVDK \"The Visual Development Kit\" version %d.%d.%d"
+"<span foreground=\"sienna\" font_desc=\"times bold 12\">"
+"VDK \"The Visual Development Kit\"\nversion %d.%d.%d"
 "</span>"
 "<span font_desc=\"helvetica bold 10\">"
-"\n\t\t\t\tA LGPL'd C++ framework based on glib %d.%d.%d - gtk+ %d.%d.%d\n"
+"\nA LGPL'd C++ framework based on\nglib %d.%d.%d - gtk+ %d.%d.%d\n"
 "\n"
 "<b><span foreground=\"sienna\">"
 "Original author:"
@@ -586,7 +728,7 @@ static char* introduction =
 "<b><span foreground=\"sienna\">"
 "VDK team:\n"
 "</span></b>"
-"<span foreground=\"navy blue\" font_desc=\"times bold 12\">"
+"<span foreground=\"navy blue\" font_desc=\"times bold 10\">"
 "\t<i>Mario Motta"
 "\tIonutz Borcoman"
 "\tTim Lorenz\n"
@@ -698,6 +840,9 @@ TestvdkForm::GUISetup(void)
   openMenu->Caption = "_View sources";
   openMenu->SetSize(98,25);
   Menu0->Add(openMenu,l_justify,1,1,0);
+  filechooser = new VDKMenuItem(this,"filechooser",NULL);
+  filechooser->Caption = "File  _Chooser";
+  Menu0->Add(filechooser,l_justify,1,1,0);
   Menu0->Separator();
   quitMenu = new VDKMenuItem(this,"quitMenu",NULL);
   quitMenu->Caption = "_Quit";
@@ -716,10 +861,10 @@ TestvdkForm::Setup(void)
 bool
 TestvdkForm::CanClose(void)
 {
-  bool result =  Application()->MessageBox(
+  bool result =  Application()->VDKMessageBox(
 					   "VDK \"The Visual Development Kit\"",
 					   "Really do you want quit VDK test program ?",
-					   MB_ICONQUESTION | MB_YESNO,NULL,NULL,5000) == IDYES;
+					   VDK_ICONQUESTION | VDK_YESNO,NULL,NULL,5000) == VDK_IDYES;
   return result;
 
 }
@@ -758,6 +903,36 @@ TestvdkApp::Setup(void)
   RESPONSE METHODS
 */
 
+/*
+  answers to view sources menu  menu activation
+*/
+bool
+TestvdkForm::OnfilechooserActivate(VDKObject* sender)
+{
+  FileStringArray selections;
+  VDKFileChooser* fc = new VDKFileChooser(this, &selections,"Apri files");
+  fc->MultiSelection = true;
+  fc->AddFilterPattern("All files","*");
+  fc->AddFilterPattern("C sources","*.c");
+  fc->AddFilterPattern("CC sources","*.cc");
+  fc->AddFilterPattern("C/CC headers","*.h");
+  fc->AddMimeType("images PNG","image/png");
+  fc->SetDefaultFilter("All files");
+  fc->Action = GTK_FILE_CHOOSER_ACTION_OPEN;
+  fc->ShowModal();
+  if(selections.size() == 1)
+    {
+    printf("\nSelected:%s",(char*) selections[0]);
+    fflush(stdout);
+    }
+  else if(selections.size() > 1)
+    {
+      for(int t = 0; t < selections.size(); t++)
+	    printf("\nSelected:%s",(char*) selections[t]);
+      fflush(stdout);
+    }
+   return true;
+}
 /*
   answers to view sources menu  menu activation
 */
@@ -873,6 +1048,6 @@ TestvdkForm::OnTestIt(VDKObject* sender)
 void 
 TestvdkForm::OnResize(VDKForm* form, VDKPoint& s)
 {
-  printf("\nOnResize() - %d,%d",s.x,s.y);
-  fflush(stdout);
+  // printf("\nOnResize() - %d,%d",s.x,s.y);
+  // fflush(stdout);
 }
