@@ -38,9 +38,12 @@ class TestvdkForm: public VDKForm
   // gui object declarations
   void GUISetup(void);
   VDKObject* active;
+
  public:
   // some place holders for run-time constructed widgets
   VDKCustomSortedList* sortedlist_widget;
+  VDKComboEntry* cbentry;
+  VDKCheckButton* chbox;
   // constructor
   TestvdkForm(VDKApplication* app, char* title);
   ~TestvdkForm();
@@ -69,7 +72,7 @@ class TestvdkForm: public VDKForm
   VDKMenubar* menubar;
   VDKMenuItem* MenuItem0;
   VDKMenu* Menu0;
-  VDKMenuItem* openMenu;
+  VDKMenuItem* openMenu,*filechooser;
   VDKMenuItem* MenuItem2;
   VDKMenuItem* quitMenu;
   VDKLabel* introduce_vdk;
@@ -77,6 +80,7 @@ class TestvdkForm: public VDKForm
  public:
 
   DECLARE_SIGNAL_MAP(TestvdkForm);
+  bool OnfilechooserActivate(VDKObject* sender);
   bool OnquitMenuActivate(VDKObject* sender);
   bool OnopenMenuActivate(VDKObject* sender);
   bool OnTestIt(VDKObject* sender);
@@ -88,6 +92,11 @@ class TestvdkForm: public VDKForm
   bool CanClose();
   bool OnTimerTick(VDKObject* sender);
   void OnResize(VDKForm* form, VDKPoint& s);
+  bool OnComboEntryActivated(VDKObject* sender);
+  bool OnComboEntryChanged(VDKObject* sender);
+  bool OnComboEntryFocusIn(VDKObject* sender);
+  bool OnComboEntryFocusOut(VDKObject* sender);
+  bool OnCheckBoxToggled(VDKObject* sender);
   /*
     declaring signal and events
     dynamics tables
