@@ -208,6 +208,7 @@ TreeViewComponent::OnClearClicked(VDKObject* sender)
   VDKTreeViewModel* model = tree->Model;
   model->Clear();
   tree->Selections().flush();
+  return true;
 }
 
 bool
@@ -380,7 +381,7 @@ TreeViewComponent::Setup()
   /*
     makes a tree with a void data model (will be completed on tree realize signal)
   */
-  tree = new VDKTreeView(Owner(),NULL/*,GTK_SELECTION_MULTIPLE*/);
+  tree = new VDKTreeView(Owner(),NULL,GTK_SELECTION_MULTIPLE);
   tree->SetSize(-1,200);
   /*
     add tree to scrolled and scrolled to component box
