@@ -477,7 +477,7 @@ if(pixmap)
 /*
  */ 
 void 
-VDKCanvas::SetForeground(VDKRgb rgb, GtkStateType state = GTK_STATE_NORMAL)
+VDKCanvas::SetForeground(VDKRgb rgb, GtkStateType state)
 {
   setFg = true;  
   if(Widget()->window)
@@ -502,7 +502,7 @@ VDKCanvas::SetForeground(VDKRgb rgb, GtkStateType state = GTK_STATE_NORMAL)
 
 
 void 
-VDKCanvas::SetBackground(VDKRgb rgb, GtkStateType state = GTK_STATE_NORMAL)
+VDKCanvas::SetBackground(VDKRgb rgb, GtkStateType state)
 {
 
 //    setBg = true;  
