@@ -78,9 +78,9 @@ VDKEntry::VDKEntry(VDKForm* owner, int maxLen, char* def):
   Hidden("Hidden", this, false, &VDKEntry::SetHidden)
 {
   if(maxLen)
-    widget = gtk_entry_new_with_max_length(maxLen);
+    widget = sigwid = gtk_entry_new_with_max_length(maxLen);
   else
-    widget = gtk_entry_new();
+    widget = sigwid = gtk_entry_new();
   if(def)
     SetText(def);
   s_activated.obj = this;
@@ -194,3 +194,125 @@ else
     gtk_widget_size_request (WrappedWidget(), NULL);
   }
 }
+
+// COMPLETION SUPPORT 
+static GtkTreeModel *
+create_string_completion_model (char* completion_list[]);
+
+static gboolean
+match_func (GtkEntryCompletion *completion,
+	    const gchar        *key,
+	    GtkTreeIter        *iter,
+	    gpointer            user_data);
+/*
+  completion_list must be a NULL terminating string array;
+ */
+
+void 
+VDKEntry::SetCompletion(char** completion_list)
+{
+  // uses any previous model if any
+  GtkEntryCompletion * completion = gtk_entry_get_completion (GTK_ENTRY (widget));
+  GtkTreeModel *completion_model = NULL;
+  if(!completion)
+    {
+      /* Create the completion object */
+      completion = gtk_entry_completion_new ();
+      /* Assign the completion to the entry */
+      gtk_entry_set_completion (GTK_ENTRY (widget), completion);
+      g_object_unref (completion);
+    }
+  /* Create a tree model and use it as the completion model */
+  completion_model = create_string_completion_model (completion_list);
+  gtk_entry_completion_set_model (completion, completion_model);
+  g_object_unref (completion_model);
+  /* Use model column 0 as the text column */
+  gtk_entry_completion_set_text_column (completion, 0);
+  gtk_entry_completion_set_minimum_key_length (completion, 1);
+  gtk_entry_completion_set_match_func (completion, match_func, NULL, NULL);
+  return;
+}
+//
+void 
+VDKEntry::AddCompletionItem(char* completion_item)
+{
+  GtkEntryCompletion * completion = gtk_entry_get_completion (GTK_ENTRY (widget));
+  GtkListStore *store = NULL;
+  if(completion)
+    {
+      GtkTreeIter iter; 
+      store = GTK_LIST_STORE (gtk_entry_completion_get_model (completion));
+      if(store)
+	{
+	  gtk_list_store_append (store, &iter);
+	  gtk_list_store_set (store, &iter, 0, completion_item, -1);
+	}
+    }
+}
+//
+void 
+VDKEntry::RemoveCompletionItem(char* completion_item)
+{
+  GtkEntryCompletion * completion = gtk_entry_get_completion (GTK_ENTRY (widget));
+  GtkTreeModel *store = NULL;
+  if(completion)
+    {
+      GtkTreeIter iter; 
+      store = gtk_entry_completion_get_model (completion);
+      if(store)
+	{
+	  gchar *item = NULL;  
+	  for(bool flag = gtk_tree_model_get_iter_first(store,&iter);
+	      flag; flag = gtk_tree_model_iter_next(store,&iter))
+	    {
+	        gtk_tree_model_get (store, &iter, 0, &item, -1);
+		if(!strcmp(item,completion_item))
+		  {
+		    gtk_list_store_remove (GTK_LIST_STORE(store),&iter);
+		    break;
+		  }		  
+	    }
+	}
+    }
+}
+/*
+---------- SUPPORT ---------
+*/
+static gboolean
+match_func (GtkEntryCompletion *completion,
+	    const gchar        *key,
+	    GtkTreeIter        *iter,
+	    gpointer            user_data)
+{
+  gchar *item = NULL;
+  GtkTreeModel *model;
+
+  gboolean ret = FALSE;
+
+  model = gtk_entry_completion_get_model (completion);
+
+  gtk_tree_model_get (model, iter, 0, &item, -1);
+
+  if (item != NULL)
+    {
+      if (strncmp (key, item, strlen (key)) == 0)
+	ret = TRUE;
+      g_free (item);
+    }
+
+  return ret;
+}
+
+GtkTreeModel *
+create_string_completion_model (char* completion_list[])
+{
+  GtkListStore *store;
+  GtkTreeIter iter;
+  store = gtk_list_store_new (1, G_TYPE_STRING);
+  for(int t = 0; completion_list[t]; t++)
+    {
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (store, &iter, 0, completion_list[t], -1);
+    }
+  return GTK_TREE_MODEL (store);
+}
