@@ -165,7 +165,7 @@ VDKForm::ConfigureEvent(GtkWidget* wid ,
   g_return_val_if_fail(wid != NULL, FALSE);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   if (!GTK_WIDGET_VISIBLE(wid))
-    return TRUE; /* Can't get its  size/pos */
+    return FALSE; /* Can't get its  size/pos */
   VDKPoint p;
   if(form->never_showed)
     p = VDKPoint(wid->allocation.x,wid->allocation.y);
