@@ -47,15 +47,17 @@ VDKNumericEntry::KeyEvent(GtkWidget *wid, GdkEventKey *ev, gpointer data)
     case GDK_Right:
     case GDK_Left:
     case GDK_Return:
+    case GDK_End:
+    case GDK_Home:
     case '.':
     case ',':
     case '-':
       break;
     default:
       if(ev->keyval < 48 || ev->keyval > 57)
-	gtk_signal_emit_stop_by_name(GTK_OBJECT(wid),"key_press_event");
+	return TRUE; //gtk_signal_emit_stop_by_name(GTK_OBJECT(wid),"key_press_event");
     }
-  return TRUE;
+  return FALSE;
 }
 
 /*
