@@ -35,19 +35,21 @@ VDKTooltip::VDKTooltip(VDKForm* owner,VDKObject *tipped,
 {
   GtkWidget* tippedGtkWidget = NULL;
   VDKCustom* custom = NULL;
-  tip = new char[std::strlen(tipString)+1];
-  std::strcpy(tip,tipString);
   tooltip = gtk_tooltips_new();
   widget  = (GtkWidget*) tooltip;
   if( (custom = dynamic_cast<VDKCustom*>(tipped)) )
     tippedGtkWidget = custom->CustomWidget();
   else
     tippedGtkWidget = tipped->WrappedWidget();
-  gtk_tooltips_set_tip(tooltip,tippedGtkWidget,tip,NULL);
-  gtk_tooltips_set_delay(tooltip,delay ? delay : 700);
-  tipped->AddItem(this);
-  gtk_tooltips_force_window (tooltip);
-  
+  if(tipString)
+    {
+      tip = new char[std::strlen(tipString)+1];
+      std::strcpy(tip,tipString);
+      gtk_tooltips_set_tip(tooltip,tippedGtkWidget,tip,NULL);
+      gtk_tooltips_set_delay(tooltip,delay ? delay : 700);
+      gtk_tooltips_force_window (tooltip);
+    }
+  tipped->AddItem(this);  
 }
 
 VDKTooltip::~VDKTooltip()
