@@ -239,9 +239,9 @@ char* calendardate::InternalBuffer()
 expect a date in
 yyyymmdd format
 */
-calendardate MakeDate(char* s)
+calendardate MakeDate(char* s,int mode)
 {
-calendardate today;
+calendardate today(mode);
 int d,m,y;
 if(std::strlen(s) != 8)
     return today;
@@ -252,5 +252,5 @@ buffer[6] = '\0';
 m = std::atoi(&buffer[4]);
 buffer[4] = '\0';
 y = std::atoi(buffer);
-return calendardate(d,m,y);
+return calendardate(d,m,y,mode);
 }
