@@ -37,30 +37,34 @@ static char floating_token[256];
 VDKEditor::VDKEditor(VDKForm* owner, GtkSourceBuffer* buff):
   VDKObject(owner),
   Syntax("Syntax",this,true,&VDKEditor::SetSyntax),
-    Pointer("Pointer",this,0,&VDKEditor::SetPointer,
-        &VDKEditor::GetPointer),
-    Column("Column",this,0,&VDKEditor::SetColumn,
-            &VDKEditor::GetColumn),
-    Line("Line",this,0,&VDKEditor::SetLine,
-            &VDKEditor::GetLine),
-    Length("Length",this,0,&VDKEditor::GetLength),
-    Editable("Editable",this,true,&VDKEditor::SetEditable,
-            &VDKEditor::GetEditable),
-    MaxUndo("MaxUndo",this,5),
-    LineAutoSelect("LineAutoSelect",this,false), // dummy
-    ShowLineNumbers("ShowLineNumbers",this,false,&VDKEditor::SetShowLineNumbers),
-    FirstVisibleLine("FirstVisibleLine",this,0,&VDKEditor::GetFirstVisibleLine),
-  LastVisibleLine("LastVisibleLine",this,0,&VDKEditor::GetLastVisibleLine)
+  Pointer("Pointer",this,0,&VDKEditor::SetPointer,
+	    &VDKEditor::GetPointer),
+  Column("Column",this,0,&VDKEditor::SetColumn,
+	   &VDKEditor::GetColumn),
+  Line("Line",this,0,&VDKEditor::SetLine,
+	 &VDKEditor::GetLine),
+  Length("Length",this,0,&VDKEditor::GetLength),
+  Editable("Editable",this,true,&VDKEditor::SetEditable,
+	     &VDKEditor::GetEditable),
+ TabStop("TabStop",this,5,&VDKEditor::SetTabStop,
+	     &VDKEditor::GetTabStop),
+  MaxUndo("MaxUndo",this,5),
+  LineAutoSelect("LineAutoSelect",this,false), // dummy
+  ShowLineNumbers("ShowLineNumbers",this,false,&VDKEditor::SetShowLineNumbers),
+  FirstVisibleLine("FirstVisibleLine",this,0,&VDKEditor::GetFirstVisibleLine),
+  LastVisibleLine("LastVisibleLine",this,0,&VDKEditor::GetLastVisibleLine),
+  Changed("Changed",this,false)// ,&VDKEditor::SetChanged,&VDKEditor::GetChanged)
 
 {
-  GtkTextTagTable *table;
+  // GtkTextTagTable *table;
   // initializes buffer
   if(!buff)
     {
-      table = gtk_text_tag_table_new();  
-      buffer = GTK_SOURCE_BUFFER(gtk_source_buffer_new(table));
-      g_object_ref(table);
-      GTK_TEXT_BUFFER(buffer)->tag_table = table;
+      //table = gtk_text_tag_table_new();  
+      buffer = GTK_SOURCE_BUFFER(gtk_source_buffer_new(NULL));
+      //      g_object_ref(table);
+      // GTK_TEXT_BUFFER(buffer)->tag_table = table;
+      
     }
   else
     buffer = buff;
@@ -69,7 +73,7 @@ VDKEditor::VDKEditor(VDKForm* owner, GtkSourceBuffer* buff):
   				    GTK_POLICY_AUTOMATIC,
 				    GTK_POLICY_AUTOMATIC);
 
-  view = gtk_source_view_new_with_buffer (GTK_TEXT_BUFFER(buffer));
+  view = gtk_source_view_new_with_buffer (GTK_SOURCE_BUFFER(buffer));
   sigwid = view;
   gtk_container_add (GTK_CONTAINER (widget), view);
   gtk_widget_show(view);
@@ -84,6 +88,9 @@ VDKEditor::HandleRealize(GtkWidget* widget, gpointer gp)
   if(editor)
     {
       editor->SignalEmit("realize");
+      g_signal_connect_closure(G_OBJECT(editor->buffer),"changed",
+			       g_cclosure_new( G_CALLBACK(VDKEditor::OnBufferChanged),
+					       editor,NULL), FALSE);
     }
 }
 
@@ -129,31 +136,16 @@ VDKEditor::SetForeground(VDKRgb rgb, GtkStateType state)
 bool 
 VDKEditor::LoadFromFile(const char* filename)
 {
-  FILE* fp;
-  char* edbuff,*p;
-  fp = fopen(filename,"r");
-  if(fp)
+  GError *err = NULL;
+  Clear();
+  if(gtk_source_buffer_load (GTK_SOURCE_BUFFER(buffer),filename,&err))
     {
-      int c;
-      struct stat info;
-      stat(filename,&info);
-      unsigned int size = info.st_size;
-      edbuff = p = new char[size];
-      while( (c = fgetc(fp)) != EOF)
-        	*p++ = (char) c;
-      fclose(fp);
-      if(buffer)
-        {
-          gtk_text_buffer_set_text(GTK_TEXT_BUFFER(buffer),edbuff,size);
-          return true;
-        }
-      else
-        return false;
+      Changed = false;
+      return true;
     }
   else
-    {
-      return false;
-    }
+    return false;
+  
 }
 
 /*
@@ -211,7 +203,7 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 
   GtkTextTag* tag;
   GtkTextTagTable* table = gtk_text_buffer_get_tag_table (GTK_TEXT_BUFFER(buffer));
-
+  GList *list = NULL;
   // keywords tags
   if(key_color)
     {
@@ -239,7 +231,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
                  key_font ? "font_desc" : NULL,
                  key_font ? key_font->AsPangoFontDescription(): NULL,
                  NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  // gtk_text_tag_table_add (table, tag);
+	  list = g_list_append (list, (gpointer) tag);
 	}
 
       tag = gtk_text_tag_table_lookup  (table,"C++-funcs");
@@ -258,7 +251,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       key_font ? "font_desc" : NULL,
 		       key_font ? key_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	  list = g_list_append (list, (gpointer) tag);
 	}
       }
 
@@ -281,7 +275,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       gtk_font ? "font_desc" : NULL,
 		       gtk_font ? gtk_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
 
       tag = gtk_text_tag_table_lookup  (table,"gnu_typedef");
@@ -299,7 +294,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       gtk_font ? "font_desc" : NULL,
 		       gtk_font ? gtk_font->AsPangoFontDescription() : NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
 
       tag = gtk_text_tag_table_lookup  (table,"vdk_functions");
@@ -317,7 +313,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		   gtk_font ? "font_desc" : NULL,
 		   gtk_font ? gtk_font->AsPangoFontDescription(): NULL,
 		   NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
       }
   // macro tags
@@ -338,7 +335,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       macro_font ? "font_desc" : NULL,
 		       macro_font ? macro_font->AsPangoFontDescription() : NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
     }
 
@@ -361,7 +359,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       pp_font ? "font_desc" : NULL,
 		       pp_font ? pp_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
     }
   // constants tags
@@ -382,7 +381,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       const_font ? "font_desc" : NULL,
 		       const_font ? const_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
       
       tag = gtk_text_tag_table_lookup  (table,"numbers");
@@ -400,7 +400,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       const_font ? "font_desc" : NULL,
 		       const_font ? const_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
 
       tag = gtk_text_tag_table_lookup  (table,"string");
@@ -418,7 +419,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       const_font ? "font_desc" : NULL,
 		       const_font ? const_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
     }
   //
@@ -439,7 +441,8 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       comment_font ? "font_desc": NULL,
 		       comment_font ? comment_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
       
       tag = gtk_text_tag_table_lookup  (table,"description_multiline");
@@ -457,9 +460,15 @@ VDKEditor::InstallSyntaxTable (VDKColor *key_color,
 		       comment_font ? "font_desc": NULL,
 		       comment_font ? comment_font->AsPangoFontDescription(): NULL,
 		       NULL);
-	  gtk_text_tag_table_add (table, tag);
+	  //	  gtk_text_tag_table_add (table, tag);
+	list = g_list_append (list, (gpointer) tag);
 	}
       }
+  if(list)
+    {
+     	gtk_source_buffer_install_regex_tags (GTK_SOURCE_BUFFER(buffer), list);
+	g_list_free (list);
+    }
 }
 /*
 */
@@ -499,7 +508,7 @@ VDKEditor::Clear()
 /*
 */
 gchar* 
-VDKEditor::GetChars(int start, int end = -1)
+VDKEditor::GetChars(int start, int end)
 {
   GtkTextIter first,last;
   gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(buffer),&first,start);
@@ -515,6 +524,15 @@ VDKEditor::GetChars(int start, int end = -1)
 bool 
 VDKEditor::SaveToFile(const char* filename)
 {
+  GError *err = NULL;
+  if(gtk_source_buffer_save (GTK_SOURCE_BUFFER(buffer),filename,&err))
+    {
+      Changed = false;
+      return true;
+    }
+  else
+    return false;
+  /*
   FILE* fp;
   fp = fopen(filename,"w+b");
   if(fp)
@@ -533,11 +551,12 @@ VDKEditor::SaveToFile(const char* filename)
   }
   else 
     return false;
+  */
 }
 /*
 */
 void 
-VDKEditor::TextInsert(const char* txt, int nchar = -1)
+VDKEditor::TextInsert(const char* txt, int nchar)
 {
   gtk_text_buffer_insert_interactive_at_cursor (GTK_TEXT_BUFFER(buffer),txt,nchar,
 						gtk_text_view_get_editable(GTK_TEXT_VIEW(view)));
@@ -759,12 +778,14 @@ VDKEditor::AddToken()
 bool
 VDKEditor::Undo(void)
 {
+  /*
   if(sigwid && (gtk_source_buffer_get_undo_count(buffer)) > 0) 
      {
        gtk_source_buffer_undo(buffer);
        return true;
      }
    else
+  */
      return false;
 }
 // SETTING PROPERTIES
@@ -847,6 +868,64 @@ VDKEditor::GetLine()
     }
   return line;
 }
+/*
+ */
+bool 
+VDKEditor::AddMarkIcon(VDKPixbuf* icon, const char * key, bool overwrite)
+{
+  if(!icon)
+    return false;
+  else
+    return  gtk_source_view_add_pixbuf(GTK_SOURCE_VIEW(view), 
+				       key, icon->AsGdkPixbuf() , 
+				       overwrite);
+}
+/*
+ */
+void 
+VDKEditor::AddLineMark(int line, const char* icon_key)
+{
+    if(!gtk_source_buffer_line_has_markers (GTK_SOURCE_BUFFER(buffer),line))
+  	gtk_source_buffer_line_add_marker (GTK_SOURCE_BUFFER(buffer),line,icon_key); 
+}
+/*
+ */
+void 
+VDKEditor::RemoveLineMark(int line, const char* icon_key)
+{
+    if(!gtk_source_buffer_line_has_markers (GTK_SOURCE_BUFFER(buffer),line))
+  	gtk_source_buffer_line_remove_marker (GTK_SOURCE_BUFFER(buffer),line,icon_key); 
+}
+/*
+ */
+void 
+VDKEditor::RemoveLineMarks(int line)
+{
+ gtk_source_buffer_line_remove_markers (GTK_SOURCE_BUFFER(buffer),line); 
+}
+/*
+ */
+void 
+VDKEditor::RemoveAllLineMarks()
+{
+int end = gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (buffer));
+gtk_source_buffer_remove_all_markers (GTK_SOURCE_BUFFER(buffer),-1,end);
+gtk_widget_queue_draw(GTK_WIDGET(WrappedWidget()));  
+}
+/*
+*/
+void 
+VDKEditor::SetTabStop(int tab_stop)
+{
+  gtk_source_view_set_tab_stop(GTK_SOURCE_VIEW(view), tab_stop);
+}
+/*
+*/
+int
+VDKEditor::GetTabStop()
+{
+  return gtk_source_view_get_tab_stop(GTK_SOURCE_VIEW(view));
+}
 /*
 */
 unsigned int 
@@ -931,8 +1010,10 @@ VDKEditor::SetChanged(bool f)
 void 
 VDKEditor::SetMaxUndo(int m)
 {
+  /*
   if(sigwid)
     gtk_source_buffer_set_max_undo_stack(buffer, m);
+  */
 }
 
 /*
@@ -949,13 +1030,8 @@ VDKEditor::LocalConnect()
   // gtk_signal_connect (GTK_OBJECT (sigwid), "key_release_event", 
   // 			GTK_SIGNAL_FUNC (VDKEditor::OnKeyRelease), this);
 
-  g_signal_connect_closure(G_OBJECT(buffer),"changed",
-			   g_cclosure_new( G_CALLBACK(VDKEditor::OnBufferChanged),
-					  this,NULL), FALSE);
-  /* 
   gtk_signal_connect(GTK_OBJECT(sigwid),"realize",
 			 GTK_SIGNAL_FUNC(VDKEditor::HandleRealize), this);
-  */
 }
 
 /*
@@ -1270,7 +1346,7 @@ VDKEditor::UnselectText()
   pointer position, leaving <margin> pixels free
 */
 void 
-VDKEditor::ScrollToPos (int pointer = -1, int margin = 0)
+VDKEditor::ScrollToPos (int pointer, int margin)
 {
   if(pointer >= 0)
     Pointer = pointer;
@@ -1284,7 +1360,7 @@ VDKEditor::ScrollToPos (int pointer = -1, int margin = 0)
   Scrolls to a line,column leaving <margin> pixels free
 */
 void 
-VDKEditor::ScrollToLine(int line, int col, int margin = 0)
+VDKEditor::ScrollToLine(int line, int col, int margin)
 {
   Line = line;
   Column = col;
