@@ -50,11 +50,12 @@ VDKObject::Widget()
 {
   return widget ? GTK_WIDGET(widget): (GtkWidget*) NULL;
 }
-
+/*
+ */
 GtkWidget*
 VDKObject::ConnectingWidget()
 {
-  return sigwid ? sigwid : widget;
+  return sigwid ? GTK_WIDGET(sigwid) : widget ? GTK_WIDGET(widget): (GtkWidget*) NULL;
 }
 
 GtkWidget*
@@ -203,6 +204,7 @@ void VDKObject::SetCursor(VDKCursorType curType)
  */
 void VDKObject::ConnectDefaultEvents()
 {
+
 }
 /*
 
@@ -215,10 +217,18 @@ void VDKObject::ConnectDefaultSignals()
      {
        s_realize.obj = this;
        s_realize.signal = realize_signal;
-       gtk_signal_connect(GTK_OBJECT(WrappedWidget()),"realize",
+       GtkWidget* gtkwidget = ConnectingWidget();
+       gtk_signal_connect(GTK_OBJECT(gtkwidget),"realize",
 			  GTK_SIGNAL_FUNC(VDKObject::VDKSignalPipe),
 			  (gpointer) &s_realize);
      }
+  /*
+  gtk_widget_set_events(widget,GDK_ALL_EVENTS_MASK);
+  gtk_widget_set_events(WrappedWidget(),GDK_ALL_EVENTS_MASK);
+  */
+  //  printf("\nvoid VDKObject::ConnectDefaultSignals()");
+  // fflush(stdout);
+
 }
 /*
  */
@@ -377,17 +387,18 @@ handles events calling
 static tables routines
 =======================
  */
-void
+int
 VDKObject::VDKEventPipe(GtkWidget* w, GdkEvent* event, void* o)
 {
-  g_return_if_fail(o!= NULL);
+  g_return_val_if_fail(o!= NULL, FALSE);
   VDKObject* obj = reinterpret_cast<VDKObject*>(o);
   if(obj->VDKObjectEventResponse(w,event,o,false))
-    return;
+    return TRUE;
   VDKObject* parent;
   for(parent = obj->Parent(); parent; parent = parent->Parent())
     if(parent->VDKEventResponse(w,event,o,o, false))
-      break;
+      return TRUE;
+  return FALSE; //TRUE;
 }
 /*
 =======================
@@ -395,10 +406,10 @@ handles events calling
 dynamic list  routines
 =======================
 */
-void
+int
 VDKObject::VDKEventUnitPipe(GtkWidget* w, GdkEvent* ev, void* s)
 {
-  g_return_if_fail(s != NULL);
+  g_return_val_if_fail(s != NULL, TRUE);
   VDKObjectEventUnit* event =
     reinterpret_cast<VDKObjectEventUnit*>(s);
   VDKObject* obj = reinterpret_cast<VDKObject*>(event->obj);
@@ -406,7 +417,7 @@ VDKObject::VDKEventUnitPipe(GtkWidget* w, GdkEvent* ev, void* s)
   if(event->owner == event->obj)
     {
       if(obj->VDKEventUnitResponse(w,(char*) event->signal, ev, obj))
-	return;
+	return TRUE;
       VDKForm* f;
       /* if obj is a form, see if has an owner,
 	 in this case is a child form so try to disseminate
@@ -421,7 +432,7 @@ VDKObject::VDKEventUnitPipe(GtkWidget* w, GdkEvent* ev, void* s)
 	      bool result = 
 		owner->VDKEventUnitResponse(w,(char*) event->signal,ev,obj);
 	      if(result)
-		return;
+		return TRUE;
 	    }
 	}
     }
@@ -430,7 +441,7 @@ VDKObject::VDKEventUnitPipe(GtkWidget* w, GdkEvent* ev, void* s)
   for(parent = obj->Parent(); parent; parent = parent->Parent())
     {
       if(parent->VDKEventUnitResponse(w,(char*) event->signal,ev, obj))
-	break;
+	return TRUE;
       VDKForm* f;
       /* if parent is a form, see if has an owner,
 	 in this case is a child form so try to disseminate
@@ -442,13 +453,13 @@ VDKObject::VDKEventUnitPipe(GtkWidget* w, GdkEvent* ev, void* s)
 	  VDKForm* owner = f->Owner();
 	  if(owner)
 	    {
-	      bool result = 
-		owner->VDKEventUnitResponse(w,(char*) event->signal,ev,obj);
+	      bool result = owner->VDKEventUnitResponse(w,(char*) event->signal,ev,obj);
 	      if(result)
-		return;
+		return TRUE;
 	    }
 	}
     }
+  return FALSE;
 }
 /*
 ==================
@@ -528,6 +539,7 @@ VDKObject::SetFont(VDKFont* font)
   ItemListIterator li(items);
   for(;li;li++)
 	li.current()->SetFont(font);
+
 }
 /*
  */
@@ -536,21 +548,29 @@ VDKObject::_setFont_(GtkWidget* wid, VDKFont* font)
 {
   if(GTK_IS_WIDGET(wid) && font)
     {
-      // gtk_widget_ensure_style (wid);
-      GtkStyle* style = gtk_style_copy(gtk_widget_get_style(wid));
-      g_return_if_fail(style != NULL);
-      gtk_style_ref(style);
+	
+      //      if(!GTK_WIDGET_REALIZED(wid))
+      //	{
+      	  PangoFontDescription* font_desc = font->AsPangoFontDescription();
+      	  g_return_if_fail (font_desc != NULL);
+      	  gtk_widget_modify_font (wid,font_desc);
+	  
+	  // 	}
       /*
-	========================================
-	gdk_font_unref (style->font);
-	style->font = gdk_font_load((char*) *font);
-	gdk_font_ref (style->font);
-	=========================================
-      */
-      style->font = (GdkFont*) (*font);
-      gtk_widget_set_style(wid,style);
+      else
+	{
+	  GtkRcStyle *rc_style;
+	  rc_style = gtk_rc_style_new ();
+	  rc_style->font_desc = 
+	    pango_font_description_copy (font->AsPangoFontDescription());
+	  gtk_widget_modify_style (WrappedWidget(), rc_style);
+	  gtk_rc_style_unref (rc_style);
+	  gtk_widget_size_request (wid, NULL);
+	}
+	  */
     }
 }
+
 /*
  */
 void
@@ -558,12 +578,8 @@ VDKObject::SetForeground(VDKRgb color, GtkStateType state)
 {
   if(!widget) return;
   _setForeground_(widget,color.red,color.green,color.blue, state);
-  /*
-  ItemListIterator li(items);
-  for(;li;li++)
-    li.current()->SetForeground(color,state);
-  */
 }
+
 /*
  */
 void
@@ -571,12 +587,8 @@ VDKObject::SetBackground(VDKRgb color, GtkStateType state)
 {
   if(!widget) return;
   _setBackground_(widget,color.red,color.green,color.blue, state);
-  /*
-  ItemListIterator li(items);
-  for(;li;li++)
-	li.current()->SetBackground(color,state);
-  */
 }
+
 /*
 read background color property
  */
@@ -613,32 +625,6 @@ VDKObject::GetForeground(GtkStateType state)
   return rgb;
 }
 
-/*
-this works only on gtk 1.2.5 or greater,
-to be modified when prev gtk releases
-will be obsolete.
-*/
-/*
-void
-VDKObject::_setBackground_(GtkWidget* wid,
-			   int red,int green, int blue,
-			   GtkStateType state)
- {
-   VDKColor *color = NULL;
-   GtkRcStyle *rc_style;
-   if(!GTK_IS_WIDGET(wid))
-     return;
-   else
-     rc_style = gtk_rc_style_new();
-   rc_style->color_flags[state] = GTK_RC_BG;
-   rc_style->bg[state].red = red;
-   rc_style->bg[state].green = green;
-   rc_style->bg[state].blue = blue;
-   gtk_widget_modify_style (widget, rc_style);
-   gtk_rc_style_unref (rc_style);
- }
-*/
-
 
 void
 VDKObject::_setBackground_(GtkWidget* wid,
@@ -651,23 +637,7 @@ VDKObject::_setBackground_(GtkWidget* wid,
     return;
   else
     color = new VDKColor(Owner() ? Owner() : this ,red,green,blue);
-
-  GtkStyle* style = wid->style;
-  g_return_if_fail(style != NULL);
-  style = gtk_style_copy(gtk_widget_get_style(wid));
-  gtk_style_ref(style);
-  style->bg[state] = *(color->Color());
-  gtk_widget_set_style(wid,style);
-
-  /*
-// this one should make changes survive to theme switches
-  GtkRcStyle *rc_style = gtk_rc_style_new ();
-  g_return_if_fail(rc_style != NULL);
-  rc_style->bg[state] = *(color->Color());
-  rc_style->color_flags[state] |= GTK_RC_BG;
-  gtk_widget_modify_style (wid, rc_style);
-  gtk_rc_style_unref (rc_style);
-  */
+  gtk_widget_modify_bg (wid,state,color->Color());
 }
 /*
  */
@@ -681,21 +651,8 @@ VDKObject::_setForeground_(GtkWidget* wid,
     return;
   else
     color = new VDKColor(Owner() ? Owner() : this ,red,green,blue);
-  GtkStyle* style = gtk_style_copy(gtk_widget_get_style(wid));
-  g_return_if_fail(style != NULL);
-  gtk_style_ref(style);
-  style->fg[state] = *(color->Color());
-  gtk_widget_set_style(wid,style);
-
-  /*
-// this one should make changes survive to theme switches
-  GtkRcStyle *rc_style = gtk_rc_style_new ();
-  g_return_if_fail(rc_style != NULL);
-  rc_style->bg[state] = *(color->Color());
-  rc_style->color_flags[state] |= GTK_RC_FG;
-  gtk_widget_modify_style (wid, rc_style);
-  gtk_rc_style_unref (rc_style);
-  */
+  gtk_widget_modify_fg (wid,state,color->Color());
+  
 }
 /*
  */
@@ -716,9 +673,9 @@ VDKObject::SetTip(char* t)
   if(tip)
     tip->SetTip(t);
   else
-    // STUB
     tip = new VDKTooltip(Owner(), this, t);
 }
+
 /*
  */
 void
@@ -808,49 +765,23 @@ explicitely destroy this
 bool VDKObject::Destroy()
 {
   VDKObject* parent = NULL;
+
   for(parent = Parent() ; parent; parent = parent->Parent())
-    if( Parent()->Items().remove(this) ||
-	 Parent()->Garbages().remove(this) )
+    if( Parent()->Items().remove(this) || Parent()->Garbages().remove(this) )
       break;
-  if(parent)
+
+  if(parent && widget != NULL && GTK_IS_WIDGET(widget))
     {
 #ifdef VDKDEBUG
-      printf("\ndestroyed:%p",this);
-     fflush(stdout);
-#endif
-     if(widget && GTK_IS_WIDGET(widget))
-       {
-	 	
-	 if (parent && GTK_IS_CONTAINER(widget->parent) )
-	
-#ifdef VDKDEBUG
-	   {
-#endif
-	     gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
-#ifdef VDKDEBUG
-	     printf(" (from gtk+ container:%p)",widget);
-	     fflush(stdout);
-	   }
-#endif
-	
-	 else
-	   {
-	
-	     SetVisible(false);
-	     // vdk 0.6.3
-	     // Mario Motta at : 06/21/99
-	     // explicitely destroy gtk widget
-	     // this should reduce mem leaking
-	     gtk_widget_destroy(widget);
-	     printf("(destroying gtk+ widget:%p)",widget);
-	     fflush(stdout);
-	  }
-       }
-     delete this;
-     return true;
+      printf("\ndestroying widget:%p",Widget());
+      fflush(stdout);
+#endif      
+      gtk_widget_destroy(Widget());
+      delete this;
+      return true;
     }
-else
-  return false;
+  else
+    return false;
 }
 
 /*
@@ -868,7 +799,7 @@ void SizeObjectProp::operator = (VDKPoint p)
   value = p;
   GtkWidget* wid = object->Widget();
   if(wid)
-    gtk_widget_set_usize(wid,p.X(), p.Y());
+    gtk_widget_set_size_request(wid,p.X(), p.Y());
 }
 
 /*
@@ -881,35 +812,6 @@ SizeObjectProp::operator VDKPoint()
 }
 
 #ifdef USE_SIGCPLUSPLUS
-void
-VDKObject::make_gtksigc_connection(VDKObject* obj)
-{
-     gtk_signal_connect(GTK_OBJECT(obj->WrappedWidget()),
-		     "key_press_event",
-		     GTK_SIGNAL_FUNC(&VDKObject::_handle_key_press),
-		     (gpointer) obj);
-     gtk_signal_connect(GTK_OBJECT(obj->WrappedWidget()),
-		     "key_release_event",
-		     GTK_SIGNAL_FUNC(&VDKObject::_handle_key_release),
-		     (gpointer) obj);
-}
-
-void
-VDKObject::_handle_key_press(GtkWidget* wid, GdkEventKey* eve,
-			     gpointer gp)
-{
-     VDKObject* obj=reinterpret_cast<VDKObject*>(gp);
-     obj->OnKeyPress(obj, eve->string);
-}
-
-void
-VDKObject::_handle_key_release(GtkWidget* wid, GdkEventKey* eve,
-			       gpointer gp)
-{
-     VDKObject* obj=reinterpret_cast<VDKObject*>(gp);
-     obj->OnKeyRelease(obj, eve->string);
-}
-
 // Compiled from here in order to avoid complicated conditionals
 // in makefile, will change in near future
 #include "sigc_events.cc"
