@@ -156,9 +156,7 @@ VDKString::operator == (const VDKString& s) const
 int 
 VDKString::operator <( const VDKString& s) const 
 {
-  if(p->s == s.p->s) // can be 0 either
-    return true;
-  else if ((p->s == 0) || (s.p->s == 0))
+  if ((p->s == 0) || (s.p->s == 0))
     return false;
   else
     return std::strcmp(p->s,s.p->s) < 0; 
@@ -167,9 +165,7 @@ VDKString::operator <( const VDKString& s) const
 int 
 VDKString::operator>(const VDKString& s) const 
 {
-  if(p->s == s.p->s) // can be 0 either
-    return true;
-  else if ((p->s == 0) || (s.p->s == 0))
+  if ((p->s == 0) || (s.p->s == 0))
     return false;
   else
     return std::strcmp(p->s,s.p->s) > 0; 
@@ -446,7 +442,7 @@ VDKString::Sprintf(const char* format, ...)
 }
 
 VDKString&
-VDKString::GetPart(unsigned int i, const char sep = '|')
+VDKString::GetPart(unsigned int i, const char sep)
 {
 	unsigned int L;
 	char szSep[2];
@@ -568,7 +564,7 @@ VDKString::RPad(unsigned int len, const char car)
 }
 
 VDKString&
-VDKString::DoubleChar(const char car = '\'')
+VDKString::DoubleChar(const char car)
 {
 	char DCar[3];
 	VDKString temp, rslt;
