@@ -741,17 +741,18 @@ void visit_selection  (GtkTreeModel *model,  GtkTreePath *path,  GtkTreeIter *it
 {
   VDKTreeViewIter i(model);
   VDKTreeView* tree = reinterpret_cast<VDKTreeView*>(gp);
-  //  gtk_tree_model_get_iter (model, &i, path);  
+  gtk_tree_model_get_iter (model, &i, path);  
   /*
     uhmmm...
     using GtkTreeIter private data could not be a good idea on compatibility side,
     in  other hand i suspect a O(n2) time using gtk_tree_model_get_iter()
   */
+  /*
   i.stamp = iter->stamp;
   i.user_data = iter->user_data;
   i.user_data2 = iter->user_data2;
   i.user_data3 = iter->user_data3;
-
+  */
   tree->Selections().add(i);
 }
 
@@ -874,7 +875,12 @@ VDKTreeView::RemoveSelected(void)
   GetSelections();
   VDKTreeViewModel* model = Model;
   VDKTreeViewIterListIterator li(Selections());
-  for(li.last();li;li--)
-    model->Remove(&li.current());
+  if(Selections().size() == 1)
+    model->Remove(&(Selections()[0]));
+  else if(Selections().size()> 1)
+    {
+      for(li.last();li;li--)
+	model->Remove(&li.current());
+    }
   Selections().flush();
 }
