@@ -134,7 +134,7 @@ class VDKTreeViewModel: public VDKNotCopyAble
 {
  protected:
   GtkTreeStore *model;
-  GtkTreeIter iter;
+  // GtkTreeIter iter;
  public:
   /*!
     Return underlying GtkTreeStore object
@@ -152,42 +152,43 @@ class VDKTreeViewModel: public VDKNotCopyAble
   ~VDKTreeViewModel();
   /*!
     Appends a new blank tree row
+    \param iter a not initialized iter address that will be filled with newly constructed tree row
     \param parent if not NULL the row will appended as a child
     otherwise it will be appended as a sibling.
     TIP: 
     - appending all rows as sibling will degenerate the tree into a list
-    - always make a iterator copy using returned address that points to an
-      internally handled iterator,  there is no guarantee that will remain valid.
       \code
-      GtkTreeIter iter = *model->AppendBlank();
+      GtkTreeIter iter;
+      model->AppendBlank();
       model->SetData(&iter,...);
       \endcode
   */
-  GtkTreeIter* AppendBlank(GtkTreeIter* parent = NULL);
+  void AppendBlank(GtkTreeIter* iter,GtkTreeIter* parent = NULL);
   /*!
     Prepends a new blank tree row
+    \param iter a not initialized iter address that will be filled with newly constructed tree row
     \param parent if not NULL the row will prepended as a child
     otherwise it will be prepended as a sibling.
     TIP: 
     - prepending all rows as sibling will degenerate the tree into a list
-    - always make a iterator copy using returned address that points to an
-      internally handled iterator,  there is no guarantee that will remain valid.
+
       \code
-      GtkTreeIter iter = *model->AppendBlank();
+      GtkTreeIter iter;
+      model->PrependBlank();
       model->SetData(&iter,...);
       \endcode
   */
-  GtkTreeIter* PrependBlank(GtkTreeIter* parent = NULL);
+  void PrependBlank(GtkTreeIter* iter,GtkTreeIter* parent = NULL);
   /*!
     Insert a tuple into model, tuple will be inserted in order.
+    \param iter a not initialized iter address that will be filled with newly constructed tree row
     \param tuple to be inserted
     \param parent if is NULL tuple will be inserted in order into top level nodes list
     otherwise will be inserted in order into parent children list
     \param recurse if true scans children/sibling list recursively to search insertion position
 
-    Returns newly inserted iter
    */
-  GtkTreeIter* InsertTuple(VDKTreeViewModelTuple &tuple,GtkTreeIter* parent = NULL, bool recurse = false);
+  void InsertTuple(GtkTreeIter* iter,VDKTreeViewModelTuple &tuple,GtkTreeIter* parent = NULL, bool recurse = false);
   /*!
     Clears the tree store
   */
@@ -202,8 +203,10 @@ class VDKTreeViewModel: public VDKNotCopyAble
     \param node the iterator to be set
     \param a list of pairs <column ordinal number,type value>
     the list must be -1 terminated.
+
     \code
-    GtkTreeIter   iter = *model->AppendBlank();
+    GtkTreeIter   iter;
+    model->AppendBlank();
     model->SetData(&iter, 0, "This is row 1", 1, FALSE, 2, NULL, -1);
     \endcode
   */
@@ -214,6 +217,7 @@ class VDKTreeViewModel: public VDKNotCopyAble
     \param column cell column
     \param value a string representation of GType value that will be converted
     into a GType accordlying with the model
+
     \code
     GtkTreeIter *iter = model->PrependBlank();
     model->SetCell(iter,0, "test");
@@ -251,6 +255,7 @@ class VDKTreeViewModel: public VDKNotCopyAble
     
     Tip:
     Returned buffer address should be freed by user if not NULL.
+
     \code
     //signal response method
     bool 
@@ -274,6 +279,7 @@ class VDKTreeViewModel: public VDKNotCopyAble
 	   delete[] lastname;
 	   }
 	 }
+       treeview->Selections().flush();	 
       return true;
    }
    \endcode
@@ -289,18 +295,26 @@ class VDKTreeViewModel: public VDKNotCopyAble
   void GetTuple(GtkTreeIter* node,VDKTreeViewModelTuple& tuple);
   /*!
     Move iterator to root node
-    - always make a iterator copy using returned address that points to an
-      internally handled iterator,  there is no guarantee that will remain valid.
-      \code
-      GtkTreeIter iter = *model->AppendBlank();
-      model->SetData(&iter,...);
-      \endcode
+    \param iter a not initialized iter address that will be filled with root node pointer
+
+    \code
+    GtkTreeIter iter;
+    if(model->Root(&iter))
+      {
+      char* cell = model->GetCell(&iter,0);
+      if(cell)
+        {
+	// ..
+        delete[] cell;
+	}
+     }
    */
-  GtkTreeIter* Root();
+  bool Root(GtkTreeIter* iter);
   /*!
     Move iterator forward at present level
+    \param iter a not initialized iter address that will be filled with next node pointer
    */
-  GtkTreeIter* Next();
+  bool Next(GtkTreeIter* iter);
   /*!
     Returns true if iter has a child
     \param iter
@@ -308,15 +322,19 @@ class VDKTreeViewModel: public VDKNotCopyAble
   bool HasChild(GtkTreeIter* iter)
     { return gtk_tree_model_iter_has_child (GTK_TREE_MODEL(model), iter); }
   /*!
+    Return the child of a parent node
+    \param iter a not initialized iter address that will be filled with child node pointer
+    \param parent a valid iter address of the parent node
+
+    Returns true if <parent> has a child, <iter> left undefined otherwise
    */
-  GtkTreeIter* Child(GtkTreeIter* parent);
+  bool Child(GtkTreeIter* iter,GtkTreeIter* parent);
   /*!
     Executes a linear search (deep first on childs), returns true if <value> found
     \param iter a GtkTreeIter address to be filled with iter data if <value> found
     \param column to be scanned to execute search
     \param value a string representation of a GType value that will be converted
     into a GType accordlying with the model
-
     Supported GType's:
      - G_TYPE_CHAR
      - G_TYPE_STRING
@@ -327,6 +345,8 @@ class VDKTreeViewModel: public VDKNotCopyAble
      - G_TYPE_ULONG
      - G_TYPE_FLOAT
      - G_TYPE_DOUBLE
+
+     Returns true if found
   */
   bool  Find(GtkTreeIter* iter,int column, char* value);
 
@@ -548,12 +568,44 @@ class VDKTreeViewColumn: public VDKNotCopyAble
 
 typedef VDKList<VDKTreeViewColumn> VDKTreeViewColumnList;
 typedef VDKListIterator<VDKTreeViewColumn> VDKTreeViewColumnListIterator;
-
+/*!
+  \class VDKTreeViewIter
+  \brief Provides a wrapper for GtkTreeIter
+ */
 class VDKTreeViewIter: public GtkTreeIter
 {
+  GtkTreeModel *model;
  public:
+  /*!
+    Constructor
+    \param model data model (defaults to  NULL)
+  */
+  VDKTreeViewIter(GtkTreeModel *model= NULL): model(model) {}
+  /*!
+    \internal
+   */
+  GtkTreeModel* Model(GtkTreeModel* m = NULL) { if(m) model = m; return model; }
+  // meaningless
+  /*!
+    \internal 
+   */
   bool operator==(VDKTreeViewIter& i) { return false; }
+  /*!
+    \internal 
+   */
   bool operator<(VDKTreeViewIter& i) { return false; }
+  /*!
+    \param child_iter
+    Returns true if iterator has a child, child_iter initialized to
+    child, undefined otherwise.
+   */
+  bool Child(VDKTreeViewIter* child_iter);
+  /*!
+    \param parent_iter
+    Returns true if iterator has a parent, parent_iter initialized to
+    parent, undefined otherwise.
+   */
+  bool Parent(VDKTreeViewIter* parent_iter);
 };
 
 typedef VDKArray<VDKTreeViewIter> VDKTreeViewIterArray;
